/********************************************************************************
 * MIT Java MWE Library (jMWE) v1.0.1
 * Copyright (c) 2008-2011 Massachusetts Institute of Technology
 *
 * jMWE is distributed under the terms of the Creative Commons Attribution 3.0 
 * Unported License, which means it may be freely used for all purposes, as long 
 * as proper acknowledgment is made.  
 *******************************************************************************/

package edu.mit.jmwe.detect;

import java.io.IOException;
import java.util.Arrays;

import edu.mit.jmwe.index.IMWEIndex;

/**
 * A baseline implementation of the <code>IMWEDetector</code> interface. Runs
 * both the {@link Exhaustive} and {@link ProperNouns} detectors to find MWEs in a
 * sentence.
 * 
 * @author N. Kulkarni
 * @author M.A. Finlayson
 * @version $Id: Baseline.java 620 2011-05-08 21:13:58Z markaf $
 * @since jMWE 1.0.0
 */
public class Baseline extends CompositeDetector {

	/**
	 * Constructs the BaselineDetector from a {@link Exhaustive} and
	 * {@link ProperNouns}.
	 * 
	 * @param index
	 *            the MWE index that will back the simple lookup detector.
	 * @throws NullPointerException
	 *             if the index is <code>null</code>
	 * @since jMWE 1.0.0
	 */
	public Baseline(IMWEIndex index) throws IOException{
		super(Arrays.asList(new ProperNouns(), new Exhaustive(index)));
	}
	
}
