/********************************************************************************
 * MIT Java MWE Library (jMWE) v1.0.1
 * Copyright (c) 2008-2011 Massachusetts Institute of Technology
 *
 * jMWE is distributed under the terms of the Creative Commons Attribution 3.0 
 * Unported License, which means it may be freely used for all purposes, as long 
 * as proper acknowledgment is made.  
 *******************************************************************************/

package edu.mit.jmwe.detect;

import java.util.List;

import edu.mit.jmwe.data.IMWE;
import edu.mit.jmwe.data.IToken;
import edu.mit.jmwe.detect.score.IScorer;
import edu.mit.jmwe.detect.score.LeskScore;
import edu.mit.jwi.IDictionary;

/**
 * A filter detector that throws out MWEs whose lesk score is less than some value.
 *
 * @author M.A. Finlayson
 * @version $Id: LeskAtLeast.java 610 2011-05-06 20:05:20Z markaf $
 * @since jMWE 1.0.0
 */
public class LeskAtLeast extends FilterByScore {
	
	// final instance fields
	protected final int minScore;
	protected final IDictionary dict;

	/**
	 * Constructs a new filter that filters out MWEs whose lesk score is not at
	 * least some value.
	 * 
	 * @param detector
	 *            the wrapped detector, may not be <code>null</code>
	 * @since jMWE 1.0.0
	 */
	public LeskAtLeast(IMWEDetector detector, IDictionary dict, int minScore) {
		super(detector);
		if(dict == null)
			throw new NullPointerException();
		this.dict = dict;
		this.minScore = Math.max(minScore, 0);
	}

	/* 
	 * (non-Javadoc)
	 *
	 * @see edu.mit.jmwe.detect.FilterByScore#isGoodScore(double)
	 */
	@Override
	protected boolean isGoodScore(double score) {
		return score >= minScore;
	}

	/* 
	 * (non-Javadoc)
	 *
	 * @see edu.mit.jmwe.detect.FilterByScore#getScorer(java.util.List)
	 */
	@Override
	protected <T extends IToken> IScorer<IMWE<T>> getScorer(List<T> sentence) {
		return new LeskScore<T>(sentence, dict);
	}

}
