/********************************************************************************
 * MIT Java MWE Library (jMWE) v1.0.1
 * Copyright (c) 2008-2011 Massachusetts Institute of Technology
 *
 * jMWE is distributed under the terms of the Creative Commons Attribution 3.0 
 * Unported License, which means it may be freely used for all purposes, as long 
 * as proper acknowledgment is made.  
 *******************************************************************************/

package edu.mit.jmwe.detect;

import java.util.List;

import edu.mit.jmwe.data.IMWE;
import edu.mit.jmwe.data.IToken;
import edu.mit.jmwe.detect.score.FractionAsMWEScore;
import edu.mit.jmwe.detect.score.IScorer;

/**
 * Filters the results of its backing detector to include only those MWEs whose
 * parts, in a continuous run of tokens, are more often marked as an MWE than as
 * individual tokens.
 * 
 * @author M.A. Finlayson
 * @version $Id: MoreFrequentAsMWE.java 595 2011-05-06 01:58:29Z markaf $
 * @since jMWE 1.0.0
 */
public class MoreFrequentAsMWE extends FilterByScore {

	/**
	 * Constructs the detector from the given backing detector.
	 * 
	 * @param detector
	 *            the IMWEDetector that will be used to back this detector. May
	 *            not be </code>null</code>.
	 * @throws NullPointerException
	 *             if the backing detector is </code>null</code>
	 * @since jMWE 1.0.0
	 */
	public MoreFrequentAsMWE(IMWEDetector detector) {
		super(detector);
	}

	/* 
	 * (non-Javadoc)
	 *
	 * @see edu.mit.jmwe.detect.FilterByScore#isGoodScore(double)
	 */
	@Override
	protected boolean isGoodScore(double score) {
		return score > 0.5;
	}

	/* 
	 * (non-Javadoc)
	 *
	 * @see edu.mit.jmwe.detect.FilterByScore#getScorer(java.util.List)
	 */
	@Override
	protected <T extends IToken> IScorer<IMWE<T>> getScorer(List<T> sentence) {
		return FractionAsMWEScore.getInstance();
	}

}
