/********************************************************************************
 * MIT Java MWE Library (jMWE) v1.0.1
 * Copyright (c) 2008-2011 Massachusetts Institute of Technology
 *
 * jMWE is distributed under the terms of the Creative Commons Attribution 3.0 
 * Unported License, which means it may be freely used for all purposes, as long 
 * as proper acknowledgment is made.  
 *******************************************************************************/

package edu.mit.jmwe.detect;

import java.util.List;

import edu.mit.jmwe.data.IMWE;
import edu.mit.jmwe.data.IMarkedSentence;
import edu.mit.jmwe.data.IToken;
import edu.mit.jmwe.harness.IAnswerKey;

/**
 * A detector that finds all of the MWEs in a sentence by using an answer key.
 * <p>
 * Sentences passed to this detector must implement {@link IMarkedSentence},
 * otherwise the {@link #detect(List)} method will throw an exception.
 * 
 * @author M.A. Finlayson
 * @version $Id: Perfect.java 612 2011-05-06 20:22:54Z markaf $
 * @since jMWE 1.0.0
 */
public class Perfect implements IMWEDetector {
	
	private final IAnswerKey key;
	
	/**
	 * Constructs a new detector that uses the specified answer key
	 *
	 * @param key
	 * @since jMWE 1.0.0
	 */
	public Perfect(IAnswerKey key){
		if(key == null)
			throw new NullPointerException();
		this.key = key;
	}

	/* 
	 * (non-Javadoc)
	 *
	 * @see edu.mit.jmwe.detect.IMWEDetector#detect(java.util.List)
	 */
	public <T extends IToken> List<IMWE<T>> detect(List<T> sentence) {
		if(sentence instanceof IMarkedSentence){
			IMarkedSentence<T> marked = (IMarkedSentence<T>)sentence;
			return key.getAnswers(marked);
		} else {
			throw new IllegalArgumentException("Unable to locate answers for sentence: " + sentence);
		}
	}

}
