/********************************************************************************
 * MIT Java MWE Library (jMWE) v1.0.1
 * Copyright (c) 2008-2011 Massachusetts Institute of Technology
 *
 * jMWE is distributed under the terms of the Creative Commons Attribution 3.0 
 * Unported License, which means it may be freely used for all purposes, as long 
 * as proper acknowledgment is made.  
 *******************************************************************************/

package edu.mit.jmwe.harness.result;

/**
 * Results store, at a minimum, f-measure, precision, and recall scores and the
 * values used to calculate them.
 * 
 * @author M.A. Finlayson
 * @version $Id: IBaseResult.java 613 2011-05-06 21:31:24Z markaf $
 * @since jMWE 1.0.0
 */
public interface IBaseResult {
	
	/**
	 * Returns the precision, a double between zero and 1, inclusive.
	 * 
	 * @return the precision, a double between zero and 1, inclusive.
	 * @since jMWE 1.0.0
	 */
	public double getPrecision();

	/**
	 * Returns the recall, a double between zero and 1, inclusive.
	 * 
	 * @return the recall, a double between zero and 1, inclusive.
	 * @since jMWE 1.0.0
	 */
	public double getRecall();

	/**
	 * Returns the F1 score, a double between zero and 1, inclusive. The F1
	 * score, or f-measure, is the harmonic mean of the precision and the
	 * recall.
	 * 
	 * @return the F1 score, a double between zero and 1, inclusive.
	 * @since jMWE 1.0.0
	 */
	public double getFScore();
	
	/**
	 * Returns the total number items found.
	 *
	 * @since jMWE 1.0.0
	 */
	public int getTotalFound();
	
	/**
	 * Returns the total number of answers.
	 *
	 * @since jMWE 1.0.0
	 */
	public int getTotalAnswers();
	
	/**
	 * Returns the total number of items correctly identified.
	 *
	 * @since jMWE 1.0.0
	 */
	public int getTotalCorrect();

}
